@@ -34,6 +34,7 @@ from yellowdog_client.model import (
     NodeSearch,
     NodeStatus,
     ObjectDetail,
+    PermissionDetail,
     Role,
     Task,
     TaskGroup,
@@ -58,6 +59,7 @@ from yellowdog_cli.utils.entity_utils import (
     get_user_groups,
     list_matching_object_paths,
     substitute_ids_for_names_in_crt,
+    substitute_image_family_id_for_name_in_cst,
 )
 from yellowdog_cli.utils.interactive import confirmed, select
 from yellowdog_cli.utils.misc_utils import unpack_namespace_in_prefix
@@ -92,10 +94,23 @@ def main():
     # Always use interactive mode for selections
     ARGS_PARSER.interactive = True
 
+    if (
+        ARGS_PARSER.auto_select_all
+        or ARGS_PARSER.strip_ids
+        or ARGS_PARSER.substitute_ids
+        or ARGS_PARSER.output_file
+    ) and not ARGS_PARSER.details:
+        print_log("Automatically setting the '--details' option")
+        ARGS_PARSER.details = True
+
+    if ARGS_PARSER.details and ARGS_PARSER.strip_ids:
+        print_log("Omitting YellowDog IDs from detailed JSON objects")
+
     if ARGS_PARSER.output_file and ARGS_PARSER.details:
         if exists(ARGS_PARSER.output_file):
             if not confirmed(
-                f"Overwrite file '{ARGS_PARSER.output_file}' with resource details?"
+                f"Overwrite file '{ARGS_PARSER.output_file}' with new "
+                "resource details?"
             ):
                 return
 
@@ -107,16 +122,16 @@ def main():
         list_worker_pools()
     elif ARGS_PARSER.compute_requirements or ARGS_PARSER.instances:
         list_compute_requirements()
-    elif ARGS_PARSER.compute_templates:
+    elif ARGS_PARSER.compute_requirement_templates:
         list_compute_requirement_templates()
-    elif ARGS_PARSER.source_templates:
+    elif ARGS_PARSER.compute_source_templates:
         list_compute_source_templates()
     elif ARGS_PARSER.keyrings:
         list_keyrings()
     elif ARGS_PARSER.image_families:
         list_image_families()
     elif ARGS_PARSER.namespace_storage_configurations:
-        list_namespaces()
+        list_namespace_storage_configurations()
     elif ARGS_PARSER.allowances:
         list_allowances()
     elif ARGS_PARSER.attribute_definitions:
@@ -131,6 +146,8 @@ def main():
         list_groups()
     elif ARGS_PARSER.roles:
         list_roles()
+    elif ARGS_PARSER.permissions:
+        list_permissions()
 
 
 def check_for_valid_option() -> bool:
@@ -142,7 +159,7 @@ def check_for_valid_option() -> bool:
         ARGS_PARSER.applications,
         ARGS_PARSER.attribute_definitions,
         ARGS_PARSER.compute_requirements,
-        ARGS_PARSER.compute_templates,
+        ARGS_PARSER.compute_requirement_templates,
         ARGS_PARSER.groups,
         ARGS_PARSER.image_families,
         ARGS_PARSER.instances,
@@ -151,8 +168,9 @@ def check_for_valid_option() -> bool:
         ARGS_PARSER.namespace_storage_configurations,
         ARGS_PARSER.nodes,
         ARGS_PARSER.object_paths,
-        ARGS_PARSER.source_templates,
+        ARGS_PARSER.permissions,
         ARGS_PARSER.roles,
+        ARGS_PARSER.compute_source_templates,
         ARGS_PARSER.task_groups,
         ARGS_PARSER.tasks,
         ARGS_PARSER.users,
@@ -611,7 +629,10 @@ def list_compute_source_templates():
     cs_templates = select(CLIENT, sorted_objects(cs_templates))
     cs_template_details = [
         (
-            CLIENT.compute_client.get_compute_source_template(cs_template.id),
+            substitute_image_family_id_for_name_in_cst(
+                CLIENT,
+                CLIENT.compute_client.get_compute_source_template(cs_template.id),
+            ),
             RN_SOURCE_TEMPLATE,
         )
         for cs_template in cs_templates
@@ -700,7 +721,7 @@ def list_image_families():
     )
 
 
-def list_namespaces():
+def list_namespace_storage_configurations():
     """
     List Storage Namespaces. For now, prints a table directly rather than
     calling the printing module, due to it being a bit fiddly.
@@ -956,6 +977,11 @@ def list_roles():
     print_log("Obtaining permissions for each role ...")
     roles: List[Role] = [CLIENT.account_client.get_role(x.id) for x in role_summaries]
 
+    # Sort permissions alphabetically (contorting the type)
+    for role in roles:
+        role.permissions = list(role.permissions)
+        role.permissions.sort(key=lambda permission: permission.name)
+
     if not ARGS_PARSER.details:
         print_numbered_object_list(CLIENT, roles, object_type_name="Role")
         return
@@ -964,6 +990,21 @@ def list_roles():
         print_yd_object(selected_users)
 
 
+def list_permissions():
+    """
+    List all permissions in the account.
+    """
+    permissions: List[PermissionDetail] = CLIENT.account_client.list_permissions()
+    permissions.sort(key=lambda permission: permission.name)
+
+    if not ARGS_PARSER.details:
+        print_numbered_object_list(CLIENT, permissions, object_type_name="Permission")
+        return
+
+    for permission in select(CLIENT, permissions, object_type_name="Permission"):
+        print_yd_object(permission)
+
+
 def get_autoscaling_capacity(namespace: str) -> Dict:
     """
     Get the current autoscaling values for a namespace.
